@@ -46,7 +46,7 @@ link_public_api(int)
 typedef struct Parse_Options_s * Parse_Options;
 
 link_public_api(Parse_Options)
-     parse_options_create();
+     parse_options_create(void);
 link_public_api(int)
      parse_options_delete(Parse_Options opts);
 link_public_api(void)
@@ -254,10 +254,16 @@ link_public_api(char *)
      linkage_print_links_and_domains(Linkage linkage);
 link_public_api(char *)
      linkage_print_constituent_tree(Linkage linkage, int mode);
+link_public_api(void)
+     linkage_free_constituent_tree_str(char *str);
 link_public_api(char *)
      linkage_print_postscript(Linkage linkage, int mode);
+link_public_api(void)
+     linkage_free_postscript(char * str);
 link_public_api(char *)
      linkage_print_diagram(Linkage linkage);
+link_public_api(void)
+     linkage_free_diagram(char * str);
 link_public_api(int)
      linkage_compute_union(Linkage linkage);
 link_public_api(int)
