@@ -20,7 +20,7 @@ static int N_words_to_print;  /* version of N_words in this file for printing li
 char * trailer(int mode);
 char * header(int mode);
 
-void set_centers(Linkage linkage, int print_word_0) {
+static void set_centers(Linkage linkage, int print_word_0) {
     int i, len, tot;
     tot = 0;
     if (print_word_0) i=0; else i=1;
@@ -39,7 +39,7 @@ static int row_starts[MAX_SENTENCE];
 static int N_rows;
   /* the number of rows */
 
-void left_append_string(String * string, char * s, char * t) {
+static void left_append_string(String * string, const char * s, const char * t) {
 /* prints s then prints the last |t|-|s| characters of t.
    if s is longer than t, it truncates s.
 */
@@ -57,7 +57,7 @@ void left_append_string(String * string, char * s, char * t) {
 
 
 
-void print_a_link(String * s, Linkage linkage, int link) {
+static void print_a_link(String * s, Linkage linkage, int link) {
     Sentence sent = linkage_get_sentence(linkage);
     Dictionary dict = sent->dict;
     int l, r;
@@ -127,7 +127,7 @@ char * linkage_print_links_and_domains(Linkage linkage) {
     return links_string; 
 }
 
-char * build_linkage_postscript_string(Linkage linkage) {
+static char * build_linkage_postscript_string(Linkage linkage) {
     int link, i,j;
     int d;
     int print_word_0 = 0, print_word_N = 0, N_wall_connectors, suppressor_used;
@@ -285,8 +285,12 @@ void compute_chosen_words(Sentence sent, Linkage linkage) {
 static char picture[MAX_HEIGHT][MAX_LINE];
 static char xpicture[MAX_HEIGHT][MAX_LINE];
 
-/* String allocated with exalloc.  Needs to be freed with exfree */
-char * linkage_print_diagram(Linkage linkage) {
+/** 
+ * String allocated with exalloc.  
+ * Needs to be freed with linkage_free_diagram()
+ */
+char * linkage_print_diagram(Linkage linkage)
+{
     int i, j, k, cl, cr, row, top_row, width, flag;
     char *t, *s;
     int print_word_0 = 0, print_word_N = 0, N_wall_connectors, suppressor_used;
@@ -513,7 +517,13 @@ char * linkage_print_diagram(Linkage linkage) {
     return gr_string; 
 }
 
-char * linkage_print_postscript(Linkage linkage, int mode) {
+void linkage_free_diagram(char * s)
+{
+	exfree(s, strlen(s)+1);
+}
+
+char * linkage_print_postscript(Linkage linkage, int mode)
+{
     char * ps, * qs;
     int size;
 
@@ -527,6 +537,11 @@ char * linkage_print_postscript(Linkage linkage, int mode) {
     return qs;
 }
 
+void linkage_free_postscript(char * s)
+{
+	exfree(s, strlen(s)+1);
+}
+
 void print_disjunct_counts(Sentence sent) {
     int i;
     int c;
